@@ -33,7 +33,7 @@ Options:
   --password                    Use password identification instead of key
                                 identification. This is only provided as a
                                 convenience and thoroughly untested.
-  -p PROFILE --profile=PROFILE  Profile [default: default].
+  -p PROFILE --profile=PROFILE  Profile.
   -r --recursive                Enable directory transfer. Not yet implemented.
   --remove                      Remove remote file.
   -s --stream                   Streaming mode.
@@ -46,7 +46,7 @@ Options:
 
 """
 
-__version__ = '0.0.21'
+__version__ = '0.0.22'
 
 
 from codecs import getwriter
@@ -54,8 +54,8 @@ from ConfigParser import NoSectionError, SafeConfigParser
 from contextlib import contextmanager
 from getpass import getpass, getuser
 from locale import getpreferredencoding
-from os import fdopen, makedirs, remove
-from os.path import exists, expanduser, join
+from os import environ
+from os.path import expanduser, join
 from sys import stderr, stdin, stdout
 from traceback import format_exc
 
@@ -66,6 +66,10 @@ except ImportError:
   pass # probably in setup.py
 
 
+PROFILES_PATH = environ.get('IGLOO_PROFILES_PATH', '.igloorc')
+DEFAULT_PROFILE = environ.get('IGLOO_DEFAULT_PROFILE', None)
+
+
 class ClientError(Exception):
 
   """Base client error class.
@@ -83,9 +87,6 @@ class Client(object):
 
   """API client."""
 
-  #: Path to configuration file
-  config_file = join(expanduser('~'), '.config', 'igloo', 'config')
-
   @classmethod
   def from_profile(cls, profile, absolute_folder, **options):
     """Attempt to load configuration options.
@@ -96,15 +97,15 @@ class Client(object):
     :rtype: :class:`Client`
 
     """
-    try:
-      parser = SafeConfigParser()
-      parser.read(cls.config_file)
-      options = dict(parser.items(
-        profile,
-        vars={k: v for k, v in options.items() if isinstance(v, str)}
-      ))
-    except (IOError, NoSectionError):
-      if profile != 'default':
+    if profile:
+      try:
+        parser = SafeConfigParser()
+        parser.read(PROFILES_PATH)
+        options = dict(parser.items(
+          profile,
+          vars={k: v for k, v in options.items() if isinstance(v, str)}
+        ))
+      except (IOError, NoSectionError):
         raise ClientError('config loading error')
     if absolute_folder:
       folder = options.get('folder', None)
@@ -128,6 +129,7 @@ class Client(object):
     self.writer = writer or stdout
 
   def get_writer(self, binary=False):
+    """Returns the stream writer used by the client."""
     if binary:
       return self.writer
     else:
@@ -136,22 +138,22 @@ class Client(object):
   @contextmanager
   def get_sftp_client(self):
     """Attempt to connect via SFTP to the remote host."""
-    self.ssh = SSHClient()
-    self.ssh.load_host_keys(join(expanduser('~'), '.ssh', 'known_hosts'))
+    ssh = SSHClient()
+    ssh.load_host_keys(join(expanduser('~'), '.ssh', 'known_hosts'))
     try:
-      self.ssh.connect(self.host, username=self.user, password=self.password)
+      ssh.connect(self.host, username=self.user, password=self.password)
       try:
-        self.sftp = self.ssh.open_sftp()
+        sftp = ssh.open_sftp()
       except Exception:
         raise ClientError('unable to open sftp connection')
       else:
         try:
-          self.sftp.chdir(self.folder)
+          sftp.chdir(self.folder)
         except IOError:
           raise ClientError('invalid remote folder %r' % (self.folder, ))
-        yield self.sftp
+        yield sftp
       finally:
-        self.sftp.close()
+        sftp.close()
     except Exception as err:
       if isinstance(err, ClientError):
         raise
@@ -159,7 +161,7 @@ class Client(object):
         ssh_url = '%s@%s' % (self.user, self.host)
         raise ClientError('unable to connect to %r' % (ssh_url, ))
     finally:
-      self.ssh.close()
+      ssh.close()
 
   def get_callback(self):
     """Callback function for ``sftp.put`` and ``sftp.get``."""
@@ -212,16 +214,13 @@ class Client(object):
         else:
           writer = self.get_writer(binary)
           remote_file = sftp.file(filename, 'rb')
-          file_size = sftp.stat(filename).st_size
           remote_file.prefetch()
           try:
-            size = 0
             while True:
               data = remote_file.read(32768)
               if not len(data):
                 break
               writer.write(data)
-              size += len(data)
               writer.flush()
           finally:
             remote_file.close()
@@ -257,7 +256,7 @@ def main():
   arguments = docopt(__doc__, version=__version__)
   try:
     client = Client.from_profile(
-      profile=arguments['--profile'],
+      profile=arguments['--profile'] or DEFAULT_PROFILE,
       absolute_folder=arguments['--absolute-folder'],
       host=arguments['--host'],
       user=arguments['--user'],
@@ -276,7 +275,7 @@ def main():
     elif arguments['--remove']:
       client.remove(filename=arguments['FILENAME'])
     else:
-      filename = client.upload(
+      client.upload(
         filename=arguments['FILENAME'],
         track=arguments['--track'],
         stream=arguments['--stream'],
